Home
====

Welcome to betterproto2's documentation!

betterproto is a protobuf compiler and interpreter. It improves the experience of using
Protobuf and gRPC in Python, by generating readable, understandable, and idiomatic
Python code, using modern language features.


## Features

- Generated messages are both binary & JSON serializable
- Messages use relevant python types, e.g. ``Enum``, ``datetime`` and ``timedelta`` objects
- ``async``/``await`` support for gRPC Clients and Servers
- Generates modern, readable, idiomatic python code
